:orphan:

`plasmapy.plasma.grids`
=======================

.. currentmodule:: plasmapy.plasma.grids

.. automodapi::  plasmapy.plasma.grids

.. nbgallery::
    :caption: Examples

    /notebooks/plasma/grids_cartesian
    /notebooks/plasma/grids_nonuniform
